pub struct FilterRule {Show 21 fields
pub title: String,
pub id: Option<String>,
pub name: Option<String>,
pub taxonomy: Option<String>,
pub status: Option<Status>,
pub description: Option<String>,
pub author: Option<String>,
pub date: Option<String>,
pub modified: Option<String>,
pub related: Vec<Related>,
pub license: Option<String>,
pub references: Vec<String>,
pub tags: Vec<String>,
pub fields: Vec<String>,
pub falsepositives: Vec<String>,
pub level: Option<Level>,
pub scope: Vec<String>,
pub logsource: Option<LogSource>,
pub rules: FilterRuleTarget,
pub detection: Detections,
pub custom_attributes: HashMap<String, Value>,
}Expand description
A Sigma filter rule that modifies the detection logic of referenced rules.
Filters add additional conditions (typically exclusions) to existing rules without modifying the original rule files.
Fields
title: Stringid: Option<String>name: Option<String>taxonomy: Option<String>status: Option<Status>description: Option<String>date: Option<String>modified: Option<String>license: Option<String>references: Vec<String>fields: Vec<String>falsepositives: Vec<String>level: Option<Level>scope: Vec<String>logsource: Option<LogSource>rules: FilterRuleTargetRules this filter applies to (by ID or name), or all rules.
detection: DetectionsThe filter detection section.
custom_attributes: HashMap<String, Value>Custom attributes attached to the filter rule.