pub struct SourceFixOutcome {
pub fixed_source: String,
pub applied: usize,
pub failed: usize,
}Expand description
Outcome of applying fixes to a single YAML source string.
Fields
fixed_source: StringThe (possibly) rewritten source. Equal to the input when nothing applied (no safe fixes, all conflicts, or an unparseable document).
applied: usizeNumber of safe fixes that applied cleanly.
failed: usizeNumber of safe fixes that could not be applied (patch conflicts or an unparseable document).