major_from_str

Function major_from_str 

pub fn major_from_str(s: &str) -> Option<u32>
Parse the major component out of a release string: the leading integer of the dotted version, ignoring an optional v/V prefix ("v3.1" -> 3).